@@ -18,7 +18,8 @@ class JKSparkSession(object):
 
     @classmethod
     def appName(cls,name):
-        return cls._spark.appName(name)
+        cls._spark = cls._spark.appName(name)
+        return cls
 
     @classmethod
     def config(cls,key,value):
